==> ideaIC-15.0.3-sources.jar: com/intellij/slicer/GroupByLeavesAction.java <==
/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.slicer;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.util.PlatformIcons;

/**
 * @author cdr
 */
class GroupByLeavesAction extends AnAction {
  private final SliceTreeBuilder myTreeBuilder;
  private static final String TEXT = "Group by leaf expression";

  public GroupByLeavesAction(SliceTreeBuilder treeBuilder) {
    super(TEXT, "Show original expression values that might appear in this place", PlatformIcons.XML_TAG_ICON);
    myTreeBuilder = treeBuilder;
  }

  @Override
  public void update(AnActionEvent e) {
    e.getPresentation().setText(TEXT + (myTreeBuilder.analysisInProgress ? " (Analysis in progress)" : ""));
    e.getPresentation().setEnabled(isAvailabale());
  }

  private boolean isAvailabale() {
    return !myTreeBuilder.analysisInProgress && !myTreeBuilder.splitByLeafExpressions;
  }

  @Override
  public void actionPerformed(AnActionEvent e) {
    myTreeBuilder.switchToGroupedByLeavesNodes();
  }
}

==> ideaIC-182.4323.18-sources.jar: com/intellij/slicer/GroupByLeavesAction.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.slicer;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.util.PlatformIcons;
import org.jetbrains.annotations.NotNull;

/**
 * @author cdr
 */
public class GroupByLeavesAction extends AnAction {
  private final SliceTreeBuilder myTreeBuilder;
  private static final String TEXT = "Group by leaf expression";

  public GroupByLeavesAction(@NotNull SliceTreeBuilder treeBuilder) {
    super(TEXT, "Show original expression values that might appear in this place", PlatformIcons.XML_TAG_ICON);
    myTreeBuilder = treeBuilder;
  }

  @Override
  public void update(AnActionEvent e) {
    e.getPresentation().setText(TEXT + (myTreeBuilder.analysisInProgress ? " (Analysis in progress)" : ""));
    e.getPresentation().setEnabled(isAvailabale());
  }

  private boolean isAvailabale() {
    return !myTreeBuilder.analysisInProgress && !myTreeBuilder.splitByLeafExpressions;
  }

  @Override
  public void actionPerformed(AnActionEvent e) {
    myTreeBuilder.switchToGroupedByLeavesNodes();
  }
}
